Python: module AIGO.go.Constants

AIGO.go.Constants | index /home/dpm/projects/AIGO-0.1.0/AIGO/go/Constants.py

`This module defines constants of general utility in the PyWeaver library.
The interpretation of each constant is dependent on the context. In order to determine the precise
meaning of a constant, reference the documentation for the method/function that it is being used
with.`

Data
`` |  | ALL = 'ALL' BOTH = 'BOTH' DIRECTED = 'DIRECTED' EDGES = 'EDGES' IN = 'IN' INFINITY = inf NODES = 'NODES' OUT = 'OUT' UNDIRECTED = 'UNDIRECTED' __all__ = ['ALL', 'NODES', 'EDGES', 'DIRECTED', 'UNDIRECTED', 'BOTH', 'IN', 'OUT', 'INFINITY']